/***************************************************
  This is a library for the CAP1188 I2C/SPI 8-chan Capacitive Sensor

  Designed specifically to work with the CAP1188 sensor from Adafruit
  ----> https://www.adafruit.com/products/1602

  These sensors use I2C/SPI to communicate, 2+ pins are required to
  interface
  Adafruit invests time and resources providing this open source code,
  please support Adafruit and open-source hardware by purchasing
  products from Adafruit!

  Written by Limor Fried/Ladyada for Adafruit Industries.
  BSD license, all text above must be included in any redistribution
 ****************************************************/
//--------CAP1188 SETUP --------
#include <Wire.h>
#include <SPI.h>
#include <Adafruit_CAP1188.h>
#define CAP1188_SENSITIVITY 0x1F // Setting the sensitivity....lower the number the more sensitive!!
static const int CAP1188_RESET = 12; // Reset Pin is used for I2C or SPI
Adafruit_CAP1188 cap = Adafruit_CAP1188();
//------------------------------

//--------NEOPIXEL SETUP --------
#include <Adafruit_NeoPixel.h>
#ifdef __AVR__
#include <avr/power.h>
#endif
static const int PIN = 4;
static const int NUMPIXELS = 2;
Adafruit_NeoPixel pixels = Adafruit_NeoPixel(NUMPIXELS, PIN, NEO_GRB + NEO_KHZ800);
//------------------------------

//------- TIMING --------
unsigned long lastSampleTime = 0;
unsigned long sampleInterval = 500; // in ms

//------------------------------

//-----INCOMING VALUES-----
String incomingString; // setting string from p5.js

//-----VIBE PINS-----
static const int vibePinOne = 6;
static const int vibePinTwo = 9;

int vibeOne;
int vibeTwo;

int wait = 10;
int touchedNUM;

int lightCount = 0;
int personOneCount = 0;
int personTwoCount = 0;
int vibeCount = 0;

bool personOne = false;
bool personTwo = false;
bool light = false;
bool vibe = false;

void setup() {
  Serial.begin(9600);
  Serial.println("CAP1188 test!");
  if (!cap.begin()) { // Initialize the sensor, if using i2c you can pass in the i2c address // if (!cap.begin(0x28)) {
    Serial.println("CAP1188 not found");
    while (1);
  }
  Serial.println("CAP1188 found!");
  cap.writeRegister(CAP1188_SENSITIVITY, 0x6F);  // 2x  sensitivity THIS SEEMS TO WORK THE BEST FOR 3.5" plate sensors

  pinMode(vibePinOne, OUTPUT);
  pinMode(vibePinTwo, OUTPUT);
  pixels.begin();
  pixels.show();
}

void loop() {
  unsigned long now = millis();
  uint8_t touched = cap.touched();

  if (touched == 0) {
    // No touch detected
    return;
  }

  if (lastSampleTime + sampleInterval < now) {

    lastSampleTime = now;

    for (uint8_t i = 0; i < 8; i++) {
      if (touched & (1 << i)) {
        int currentTouch = i + 1;

        if (currentTouch == 1) { // RIGHT Light
          touchedNUM = 1;
          lightCount++;
          light = true;
          vibe = false;
        } else if (currentTouch == 2) { // TOP Person One
          touchedNUM = 2;
          personOneCount++;
          personOne = true;
          personTwo = false;
          light = false;
          vibe = false;
//          Serial.print("PersonOne: "); Serial.println(personOne);
//          Serial.print("PersonTwo: "); Serial.println(personTwo);
        } else if (currentTouch == 3) { // BOTTOM Person Two
          touchedNUM = 3;
          personTwoCount++;
          personOne = false;
          personTwo = true;
          light = false;
          vibe = false;
//          Serial.print("PersonOne: "); Serial.println(personOne);
//          Serial.print("PersonTwo: "); Serial.println(personTwo);
        } else if (currentTouch == 4) { // LEFT Vibe
          touchedNUM = 4;
          vibeCount++;
          light = false;
          vibe = true;
        }

        if (personOne == true){
          Serial.println("Active: PERSON ONE");
        } else if (personTwo == true) {
          Serial.println("Active: PERSON TWO");
        }

      }
    }
  }
  personOneFun();
  personTwoFun();
}

void personOneFun() {
  if (personOne == true && personTwo == false && light == true) {
    lightBLINK(0);
    //lightON(0); // person ONE light on
    lightOFF(1); // person two light off
    vibeOFF(0); // vibes off
    vibeOFF(1);
  } else if (personOne == true && personTwo == false && vibe == true) {
    lightOFF(0); // lights off
    lightOFF(1);
    vibeON(0); // person ONE vibe on
    vibeOFF(1); // person two vibe off
  } else {
    lightOFF(0); // lights off
    lightOFF(1);
    vibeOFF(0); // vibes off
    vibeOFF(1);
  }
  //  Serial.print("Light Count: "); Serial.println(lightCount);
  //  Serial.print("Vibe Count: "); Serial.println(vibeCount);
}

void personTwoFun() {
  if (personOne == false && personTwo == true && light == true) {
    lightBLINK(1);
    // lightON(1); // person TWO light on
    lightOFF(0); // person one light off
    vibeOFF(0); // vibes off
    vibeOFF(1);
  } else if (personOne == false && personTwo == true && vibe == true) {
    lightOFF(0); // lights off
    lightOFF(1);
    vibeON(1); // person TWO vibe on
    vibeOFF(0); // person one vibe off
  } else {
    lightOFF(0); // lights off
    lightOFF(1);
    vibeOFF(0); // vibes off
    vibeOFF(1);
  }
  //  Serial.print("Light Count: "); Serial.println(lightCount);
  //  Serial.print("Vibe Count: "); Serial.println(vibeCount);
}


void vibeON(int m) {
  if (m == 0) {
    digitalWrite(vibePinOne, HIGH);
    delay(500);
    digitalWrite(vibePinOne, LOW);
    delay(250);
  } else if (m == 1) {
    digitalWrite(vibePinTwo, HIGH);
    delay(500);
    digitalWrite(vibePinTwo, LOW);
    delay(250);
  }

}

void vibeOFF(int m) {
  if (m == 0) {
    digitalWrite(vibePinOne, LOW);
  } else if (m == 1) {
    digitalWrite(vibePinTwo, LOW);
  }
}

void lightON (int m) {
  pixels.setPixelColor(m, pixels.Color(255, 255, 255));
  pixels.show();
}

void lightOFF (int m) {
  pixels.setPixelColor(m, pixels.Color(0, 0, 0));
  pixels.show();
}

void lightBLINK (int m) {
  pixels.setPixelColor(m, pixels.Color(255, 255, 255));
  pixels.show();
  delay(750);
  pixels.setPixelColor(m, pixels.Color(0, 0, 0));
  pixels.show();
  delay(500);
  pixels.setPixelColor(m, pixels.Color(255, 255, 255));
  pixels.show();
  delay(750);
  pixels.setPixelColor(m, pixels.Color(0, 0, 0));
  pixels.show();
  delay(500);
}

